using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;

namespace GuiTestApi
{
    public partial class Settings : Form
    {
        RFID.RFIDModule _rfidModule;

        public Settings(RFID.RFIDModule rfidmodule)
        {
            InitializeComponent();

            if (rfidmodule != null)
            {
                _rfidModule = rfidmodule;
            }
            else
            {
                MessageBox.Show("No rfid module object detected", "Error", MessageBoxButtons.OK, MessageBoxIcon.Exclamation, MessageBoxDefaultButton.Button1);
            }
        }

        private void GetRFIDPropertiesValues()
        {
            ID_TEXTBOX_APIVER.Text = _rfidModule.APIVersion;
            ID_TEXTBOX_SINGLEID_TIMEOUT.Text = _rfidModule.RFIDModuleSingleIDReadTimeout.ToString();
            ID_TEXTBOX_READTAG_TIMEOUT.Text = _rfidModule.RFIDModuleTimeout.ToString();
        }

        private void TextBox_TextChanged(object sender, EventArgs e)
        {
            ID_BUTTON_OK.Text = "Save";
        }

        private void ID_BUTTON_OK_Click(object sender, EventArgs e)
        {
            if (ID_BUTTON_OK.Text.Equals("Save"))
            {
                _rfidModule.RFIDModuleTimeout = Convert.ToInt32(ID_TEXTBOX_READTAG_TIMEOUT.Text);
                if (_rfidModule.Connected)
                {
                    if (Convert.ToInt32(ID_TEXTBOX_SINGLEID_TIMEOUT.Text) > 25)
                    {
                        MessageBox.Show("Single ID timeout cannot be more the 25 seconds", "Input Error", MessageBoxButtons.OK, MessageBoxIcon.Exclamation, MessageBoxDefaultButton.Button1);
                    }
                    else
                    {
                        _rfidModule.RFIDModuleSingleIDReadTimeout = Convert.ToInt32(ID_TEXTBOX_SINGLEID_TIMEOUT.Text);
                        _rfidModule.SetTimeout(Convert.ToInt32(ID_TEXTBOX_SINGLEID_TIMEOUT.Text) * 10);
                        this.Close();
                    }
                }
                else
                {
                    MessageBox.Show("Cannot save the Single Read Timeout since there is no connection with the RFID module", "Warning", MessageBoxButtons.OK, MessageBoxIcon.Exclamation, MessageBoxDefaultButton.Button1);
                    this.Close();
                }     
            }
            else
            {
                this.Close();
            }
        }

        private void ID_BUTTON_CANCEL_Click(object sender, EventArgs e)
        {
            this.Close();
        }

        private void Settings_Load(object sender, EventArgs e)
        {
            ID_TEXTBOX_APIVER.Text = _rfidModule.APIVersion;
            ID_TEXTBOX_READTAG_TIMEOUT.Text = Convert.ToString(_rfidModule.RFIDModuleTimeout / 60);
            ID_TEXTBOX_SINGLEID_TIMEOUT.Text = Convert.ToString(_rfidModule.RFIDModuleSingleIDReadTimeout/10);
        }
    }
}